@@ -22,9 +22,11 @@ from Dhelpers.launcher import launch
 path = os.path
 
 parentfolder = path.split(__file__)[0]
-saved_folder = path.join(parentfolder,"layouts_imported_from_xkb")
+xkb_imported_folder = path.join(parentfolder, "layouts_imported_from_xkb")
+other_layout_folder = path.join(parentfolder, "other_layouts")
+
 try:
-    os.makedirs(saved_folder, exist_ok=True)
+    os.makedirs(xkb_imported_folder, exist_ok=True)
 except PermissionError:
     pass
     
@@ -36,9 +38,23 @@ def get_files(folder):
         if path.isfile(fp): yield f, fp
 
 
+class ShiftedKey:
+
+    def __init__(self, keyname, num=1):
+        self.keyname = keyname
+        assert isinstance(num, int), num >= 1
+        self.num = num
+
+    def __repr__(self):
+        ret = f"<{self.__class__.__name__}({self.keyname}"
+        if self.num > 1: ret += f", x{self.num}"
+        ret += ")>"
+        return ret
+
 class LayoutBase(ABC):
     
-    json_savefolder = saved_folder
+    ShiftedKey = ShiftedKey
+    json_savefolder = None
     folders=[]
     file_ending = ""
     available_layouts = {}
@@ -96,35 +112,67 @@ class LayoutBase(ABC):
     
     
     def __lt__(self, other):
+        if isinstance(other, str): other = self.__class__(other)
         if not isinstance(other, self.__class__): return NotImplemented
         d = {}
         kd2 = self.key_dict
         kd1 = other.key_dict
-        for key in kd2:
-            right = kd2[key][0]
+        for key, val in kd2.items():
             try:
                 left = kd1[key][0]
             except KeyError:
                 left = key
-            if left is not right: d[left] = right
+            d[left] = val
         return d
     
+    def __gt__(self, other):
+        if isinstance(other, str): other = self.__class__(other)
+        if not isinstance(other, self.__class__): return NotImplemented
+        return other < self
+
+
     
+    @classmethod
+    def translate(cls, *, source=None, to=None):
+        if source == to: raise ValueError
+        return cls(source) > cls(to)
+    
+        
+    @staticmethod
+    def create_shifted_map(key_dict):
+        out = {}
+        for key, val in key_dict.items():
+            out[val[0]] = key
+            for i in range(1, len(val)):
+                item = val[i]
+                out[item] = ShiftedKey(key,num=i)
+        return out
+        
+    
+    def send_map(self, to=None, shifted = True):
+        if to is None: to = self
+        if not isinstance(to, LayoutBase): to = Layout(to)
+        if shifted:
+            return self.create_shifted_map(self < to)
+        else:
+            conversion = self > to
+            return {name: l[0] for name, l in conversion.items()}
 
 
-
+    
+            
 
 class Layout(LayoutBase):
     
-    folders = [saved_folder]
+    
+    
+    folders = [xkb_imported_folder, other_layout_folder]
     file_ending = ".json"
     
     def get_keydict(self):
         with open(self.sourcepath()) as f: return json.load(f)
     
     
-    
-    
 class Layout_from_klfc(LayoutBase):
     #klfc command line tool needs to be installed
     #this way, json layout tables can be created.
@@ -146,6 +194,7 @@ class Layout_from_klfc(LayoutBase):
     
 class XKBLayout(Layout_from_klfc):
     
+    json_savefolder = xkb_imported_folder
     folders = ["/usr/share/X11/xkb/symbols"]
     klfc_option = "from-xkb"
 
