@@ -51,10 +51,10 @@ def adaptionmethod(target_name=None, require=False):
     raise TypeError
 
 
-
 class AdaptionFuncPlaceholder:
     def __init__(self, cls_func, target_name=None, require_target=False):
         cls_func.target_modifier = self.target_modifier
+        cls_func.adaptive_property = self.adaptive_property
         self.cls_func = cls_func
         self.__name__ = cls_func.__name__
         self.target_name = self.__name__ if target_name is None else target_name
@@ -62,6 +62,7 @@ class AdaptionFuncPlaceholder:
         self.require_target = require_target
         self.modifier_argnum = None
         self.__signature__ = inspect.signature(cls_func)
+        self.coupled_attrs = {}
     
     # def __call__(self, adaptioninstance, *args, **kwargs):
     #     """ Usage example: HookAdaptor.keyb(instance,*args,**kwargs) instead
@@ -83,15 +84,48 @@ class AdaptionFuncPlaceholder:
             raise SyntaxError("""target_modifer func must not have any
             default argument values.""")
         return func
+    
+    def adaptive_property(self, name, default=None, ty=None):
+        self.coupled_attrs[name] = (default, ty)
+        custom = "_custom_" + name
+        backend = "_backend_" + name
+        def func(adaptor_inst):
+            try:
+                custom_val = getattr(adaptor_inst, custom)
+                if custom_val is not None: return custom_val
+            except AttributeError:
+                pass
+            try:
+                backend_val = getattr(adaptor_inst, backend)
+            except AttributeError:
+                pass
+            else:
+                if backend_val not in (None, NotImplemented): return backend_val
+            if default == NotImplementedError:
+                raise NotImplementedError(f"No value for attribute {name} of "
+                              f"{adaptor_inst} found.")
+            return default
+        func.__name__ = name
+        func = property(func)
+        @func.setter
+        def func(adaptor_inst,val):
+            check_type(ty, val, allowed=(None,False,True))
+            setattr(adaptor_inst,custom,val)
+        return func
 
 
 
+
+
+        
+
 class AdaptionMethod:
     def __init__(self, placeholder, Adaptor_instance):
         check_type(AdaptionFuncPlaceholder, placeholder)
         check_type(AdaptorBase, Adaptor_instance)
         self.placeholder = placeholder
         self.cls_func = placeholder.cls_func
+        self.coupled_attrs = placeholder.coupled_attrs
         functools.update_wrapper(self, self.cls_func)
         # this will copy __doc__, __name__ and __module__, as well as signature
         self.Adaptor_instance = Adaptor_instance
@@ -162,7 +196,7 @@ class AdaptionMethod:
                 **self._called_kwargs)
         bound.apply_defaults()
         return self.target(*bound.args, **bound.kwargs)
-    
+        
     
     def set_target(self):
         backend = self.Adaptor_instance.backend
@@ -173,6 +207,19 @@ class AdaptionMethod:
             self.target_space = None
             self.backend_info = None
             return
+        self.target_space = target_space
+        self.backend_info = backend.get_info(name)
+        
+        for attr_name, tu in self.coupled_attrs.items():
+            default, check_ty = tu
+            try:
+                attr_obj = getattr(target_space, attr_name)
+            except AttributeError:
+                attr_obj = NotImplemented
+            else:
+                if inspect.isclass(check_ty): check_type(check_ty,attr_obj)
+            setattr(self.Adaptor_instance,"_backend_" + attr_name,attr_obj)
+        
         try:
             target = getattr(target_space, self.target_name)
         except AttributeError:
@@ -181,8 +228,6 @@ class AdaptionMethod:
                 f"was not found.\ntartget namespace: "
                 f" {target_space}\nbackend: {backend}")
             target = NotImplemented
-        self.target_space = target_space
-        self.backend_info = backend.method_infos.get(name, backend.main_info)
         obj, ty = target, type(target)
         if ty is types.MethodType:
             def turn_to_func(method):
@@ -267,22 +312,41 @@ class AdaptorBase(KeepInstanceRefs):
                 c = cls._first_level_subclass
                 add = f"Subclass of :class:`{c.__module__}.{c.__name__}`."
                 doc = cls.__doc__ if cls.__doc__ else ""
-                cls.__doc__ = doc + "\n\n" + add
+                cls.__doc__ = doc + "\n\n    " + add
         elif cls._subclass_level == 1:
             cls._first_level_subclass = cls
-            initdoc = cls.__init__.__doc__
-            if initdoc: cls.__doc__ += "\n" + initdoc
                 
             
     
     def __init__(self, main_info=None, *, group="default", _primary=False,
             **method_infos):
         """
+        Usually, you do not need to create Adaptor instances yourself as
+        a default instance is already available for each subclass (see
+        below).
+       
+        
+        :param str main_info: Name of the backend to be used, passed on to
+            :func:`adapt`.
+        :param str group: Name of the instance group to which the new
+            instance will belong.
+        :param _primary: Used only for internal documentation purposes. It
+            allows specifiying the primary/default instance for each instance group.
+        :param method_infos: Passed on to :func:`adapt`.
+        
+        
+        If the *main_info* and/or *method_infos* parameter is given, the new
+        instance is immediately adapted using its :func:`adapt` method.
+        
+        If neither *main_info* nor *method_infos* is specified (default),
+        and :attr:`Adpator.autoadapt_active` is ``True``,
+        choose the default backend according to the instance group and
+        `Dpowers.default_backends.py
+        <https://github.com/dp0s/Dpowers/tree/master/Dlib/Dpowers
+        /default_backends.py>`_.
+        
+        Otherwise an unadapted instance is created.
         
-        :param main_info:
-        :param group:
-        :param _primary:
-        :param method_infos:
         """
         
         super().__init__()
@@ -315,7 +379,7 @@ class AdaptorBase(KeepInstanceRefs):
                 for backend_name in self.backend_names():
                     doc += f"\n\t{self.creation_name}.adapt('{backend_name}')"
                 self.__doc__ = doc
-        self.backend = None
+        self.backend = Backend(self.__class__)
         
         for name in self.adaptionmethod_names:
             placeholder = getattr(self.__class__, name)._placeholder
@@ -336,18 +400,32 @@ class AdaptorBase(KeepInstanceRefs):
     
     
     
-    def adapt(self, main_info=None, *, warn=True, raise_error=True,
-            check_adapted=True, **method_infos):
-        """
+    def adapt(self, main_info=None, *, raise_error=True,
+            require_backend=True, **method_infos):
+        """Choose the backend for this Adaptor instance. If neither
+        *main_info* nor *method_infos* is specified, the
+        default backend for this instance group is selected, as defined in
+        the module `Dpowers.default_backends.py
+        <https://github.com/dp0s/Dpowers/tree/master/Dlib/Dpowers
+        /default_backends.py>`_.
         
-        :param main_info:
-        :param warn:
-        :param raise_error:
-        :param check_adapted:
-        :param method_infos:
-        :return:
+        :param str main_info: Name of the backend to be used.
+        :param bool raise_error: If set to ``False``, exceptions caused
+            during backend import are suppressed. A warning is printed instead.
+        :param bool require_backend: If set to ``True`` (default), a
+            ``ValueError`` will be raised if no default backend could be
+            found.
+        :param method_infos: Explanation to be added    .
+        :return: - The module object of the backend's adapt_*.py file.
+                 - ``False`` if an exception occurs but is suppressed (see
+                   parameters *raise_error* and *require_backend*).
+        :raises:
+            - ``Dpowers.AdaptionError`` if there is an exception during
+              importing the backend.
+            - ``ValueError`` if used without arguments and no default backend
+              could be found (you can disable this via *require_backend=False*).
+            
         """
-        raise_error = True
         try:
             if isinstance(main_info, Backend):
                 backend = main_info
@@ -358,20 +436,20 @@ class AdaptorBase(KeepInstanceRefs):
                 backend = Backend(self.__class__, main_info, method_infos)
         except AdaptionError as e:
             if raise_error: raise
-            if warn:
-                text = f"Encountered an Exception trying to adapt\n{self}\n"
-                for _ in range(10):
-                    if str(e):
-                        text += type(e).__name__ + ": " + str(e) + "\n"
-                    e = e.__cause__
-                    if e is None: break
-                    text += "caused by\n"
-                warnings.warn(text)
+            text = f"Encountered an Exception trying to adapt\n{self}\n"
+            for _ in range(10):
+                if str(e):
+                    text += type(e).__name__ + ": " + str(e) + "\n"
+                e = e.__cause__
+                if e is None: break
+                text += "caused by\n"
+            warnings.warn(text)
             return False
-        if backend.main_info is None and not backend.method_infos:
-            if check_adapted:
-                raise AdaptionError("Given backend information not "
+        if not backend:
+            if require_backend:
+                raise ValueError("Given backend information not "
                             "valid and none found in default backends.")
+            return False
         self.backend = backend
         for amethod in self.adaptionmethods(): amethod.set_target()
         return backend.show_target_spaces()
@@ -391,7 +469,7 @@ class AdaptorBase(KeepInstanceRefs):
     
     @property
     def is_adapted(self):
-        return self.backend is not None
+        return bool(self.backend)
     
     @classmethod
     def deactivate_autoadapt(cls):
@@ -403,14 +481,14 @@ class AdaptorBase(KeepInstanceRefs):
     
     
     @classmethod
-    def _adapt_all(cls, omit_adapted_inst=False, raise_error=True, warn=True,
+    def _adapt_all(cls, omit_adapted_inst=False, raise_error=True,
             backend_source=None):
         for inst in cls.get_instances():
             if inst.is_adapted and omit_adapted_inst: continue
             bakcend_info = inst.get_from_backend_source(
                     backend_source=backend_source)
-            inst.adapt(bakcend_info, raise_error=raise_error, warn=warn,
-                    check_adapted=False)
+            inst.adapt(bakcend_info, raise_error=raise_error,
+                    require_backend=False)
     
     @classmethod
     def adapt_all(cls, *args, **kwargs):
